@@ -221,6 +221,9 @@ class SqueakAdminServerServicer(squeak_admin_pb2_grpc.SqueakAdminServicer):
     def GetSentPaymentsForPubkey(self, request, context):
         return self.handler.handle_get_sent_payments_for_pubkey(request)
 
+    def GetSentPaymentsForPeer(self, request, context):
+        return self.handler.handle_get_sent_payments_for_peer(request)
+
     def GetSentPayment(self, request, context):
         return self.handler.handle_get_sent_payment(request)
 
@@ -236,6 +239,9 @@ class SqueakAdminServerServicer(squeak_admin_pb2_grpc.SqueakAdminServicer):
     def GetReceivedPaymentsForPubkey(self, request, context):
         return self.handler.handle_get_received_payments_for_pubkey(request)
 
+    def GetReceivedPaymentsForPeer(self, request, context):
+        return self.handler.handle_get_received_payments_for_peer(request)
+
     def SubscribeReceivedPayments(self, request, context):
         stopped = threading.Event()
 
@@ -257,6 +263,12 @@ class SqueakAdminServerServicer(squeak_admin_pb2_grpc.SqueakAdminServicer):
     def GetPaymentSummaryForSqueak(self, request, context):
         return self.handler.handle_get_payment_summary_for_squeak(request)
 
+    def GetPaymentSummaryForPubkey(self, request, context):
+        return self.handler.handle_get_payment_summary_for_pubkey(request)
+
+    def GetPaymentSummaryForPeer(self, request, context):
+        return self.handler.handle_get_payment_summary_for_peer(request)
+
     def ReprocessReceivedPayments(self, request, context):
         return self.handler.handle_reprocess_received_payments(request)
 
