@@ -88,6 +88,10 @@ class SqueakDb:
         self.author_profiles = self.profiles.alias()
         self.recipient_profiles = self.profiles.alias()
 
+        # Create aliases for squeaks
+        self.display_squeaks = self.squeaks.alias()
+        self.reply_squeaks = self.squeaks.alias()
+
     def init_with_retries(
             self,
             num_retries=INIT_NUM_RETRIES,
@@ -266,7 +270,12 @@ class SqueakDb:
         # recipient_profiles = self.profiles.alias()
 
         s = (
-            select([self.squeaks, self.author_profiles, self.recipient_profiles])
+            select([
+                self.squeaks,
+                self.author_profiles,
+                self.recipient_profiles,
+                func.count(self.reply_squeaks.c.hash).label("num_replies"),
+            ])
             .select_from(
                 self.squeaks
                 .outerjoin(
@@ -277,6 +286,15 @@ class SqueakDb:
                     self.recipient_profiles,
                     self.recipient_profiles.c.public_key == self.squeaks.c.recipient_public_key,
                 )
+                .outerjoin(
+                    self.reply_squeaks,
+                    self.reply_squeaks.c.reply_hash == self.squeaks.c.hash,
+                )
+            )
+            .group_by(
+                self.squeaks,
+                self.author_profiles,
+                self.recipient_profiles,
             )
             .where(self.squeaks.c.hash == squeak_hash)
         )
@@ -313,7 +331,12 @@ class SqueakDb:
         ))
         s = (
             # select([self.squeaks, self.profiles])
-            select([self.squeaks, self.author_profiles, self.recipient_profiles])
+            select([
+                self.squeaks,
+                self.author_profiles,
+                self.recipient_profiles,
+                func.count(self.reply_squeaks.c.hash).label("num_replies"),
+            ])
             .select_from(
                 # self.squeaks.outerjoin(
                 #     self.profiles,
@@ -328,6 +351,15 @@ class SqueakDb:
                     self.recipient_profiles,
                     self.recipient_profiles.c.public_key == self.squeaks.c.recipient_public_key,
                 )
+                .outerjoin(
+                    self.reply_squeaks,
+                    self.reply_squeaks.c.reply_hash == self.squeaks.c.hash,
+                )
+            )
+            .group_by(
+                self.squeaks,
+                self.author_profiles,
+                self.recipient_profiles,
             )
             .where(self.profile_is_following(self.author_profiles))
             .where(
@@ -372,7 +404,12 @@ class SqueakDb:
         ))
         s = (
             # select([self.squeaks, self.profiles])
-            select([self.squeaks, self.author_profiles, self.recipient_profiles])
+            select([
+                self.squeaks,
+                self.author_profiles,
+                self.recipient_profiles,
+                func.count(self.reply_squeaks.c.hash).label("num_replies"),
+            ])
             .select_from(
                 # self.squeaks.outerjoin(
                 #     self.profiles,
@@ -387,6 +424,15 @@ class SqueakDb:
                     self.recipient_profiles,
                     self.recipient_profiles.c.public_key == self.squeaks.c.recipient_public_key,
                 )
+                .outerjoin(
+                    self.reply_squeaks,
+                    self.reply_squeaks.c.reply_hash == self.squeaks.c.hash,
+                )
+            )
+            .group_by(
+                self.squeaks,
+                self.author_profiles,
+                self.recipient_profiles,
             )
             .where(
                 self.squeak_is_liked,
@@ -436,7 +482,12 @@ class SqueakDb:
         ))
         s = (
             # select([self.squeaks, self.profiles])
-            select([self.squeaks, self.author_profiles, self.recipient_profiles])
+            select([
+                self.squeaks,
+                self.author_profiles,
+                self.recipient_profiles,
+                func.count(self.reply_squeaks.c.hash).label("num_replies"),
+            ])
             .select_from(
                 # self.squeaks.outerjoin(
                 #     self.profiles,
@@ -451,6 +502,15 @@ class SqueakDb:
                     self.recipient_profiles,
                     self.recipient_profiles.c.public_key == self.squeaks.c.recipient_public_key,
                 )
+                .outerjoin(
+                    self.reply_squeaks,
+                    self.reply_squeaks.c.reply_hash == self.squeaks.c.hash,
+                )
+            )
+            .group_by(
+                self.squeaks,
+                self.author_profiles,
+                self.recipient_profiles,
             )
             .where(self.squeaks.c.author_public_key == public_key.to_bytes())
             .where(
@@ -501,7 +561,12 @@ class SqueakDb:
         ))
         s = (
             # select([self.squeaks, self.profiles])
-            select([self.squeaks, self.author_profiles, self.recipient_profiles])
+            select([
+                self.squeaks,
+                self.author_profiles,
+                self.recipient_profiles,
+                func.count(self.reply_squeaks.c.hash).label("num_replies"),
+            ])
             .select_from(
                 # self.squeaks.outerjoin(
                 #     self.profiles,
@@ -516,6 +581,15 @@ class SqueakDb:
                     self.recipient_profiles,
                     self.recipient_profiles.c.public_key == self.squeaks.c.recipient_public_key,
                 )
+                .outerjoin(
+                    self.reply_squeaks,
+                    self.reply_squeaks.c.reply_hash == self.squeaks.c.hash,
+                )
+            )
+            .group_by(
+                self.squeaks,
+                self.author_profiles,
+                self.recipient_profiles,
             )
             .where(self.squeaks.c.content.ilike(f'%{search_text}%'))
             .where(
@@ -568,7 +642,12 @@ class SqueakDb:
 
         s = (
             # select([self.squeaks, self.profiles])
-            select([self.squeaks, self.author_profiles, self.recipient_profiles])
+            select([
+                self.squeaks,
+                self.author_profiles,
+                self.recipient_profiles,
+                func.count(self.reply_squeaks.c.hash).label("num_replies"),
+            ])
             .select_from(
                 self.squeaks.join(
                     ancestors,
@@ -585,6 +664,16 @@ class SqueakDb:
                     self.recipient_profiles,
                     self.recipient_profiles.c.public_key == self.squeaks.c.recipient_public_key,
                 )
+                .outerjoin(
+                    self.reply_squeaks,
+                    self.reply_squeaks.c.reply_hash == self.squeaks.c.hash,
+                )
+            )
+            .group_by(
+                self.squeaks,
+                self.author_profiles,
+                self.recipient_profiles,
+                ancestors.c.depth,
             )
             .order_by(
                 ancestors.c.depth.desc(),
@@ -639,7 +728,12 @@ class SqueakDb:
         ))
         s = (
             # select([self.squeaks, self.profiles])
-            select([self.squeaks, self.author_profiles, self.recipient_profiles])
+            select([
+                self.squeaks,
+                self.author_profiles,
+                self.recipient_profiles,
+                func.count(self.reply_squeaks.c.hash).label("num_replies"),
+            ])
             .select_from(
                 # self.squeaks.outerjoin(
                 #     self.profiles,
@@ -654,6 +748,15 @@ class SqueakDb:
                     self.recipient_profiles,
                     self.recipient_profiles.c.public_key == self.squeaks.c.recipient_public_key,
                 )
+                .outerjoin(
+                    self.reply_squeaks,
+                    self.reply_squeaks.c.reply_hash == self.squeaks.c.hash,
+                )
+            )
+            .group_by(
+                self.squeaks,
+                self.author_profiles,
+                self.recipient_profiles,
             )
             .where(self.squeaks.c.reply_hash == squeak_hash)
             .where(
@@ -1308,6 +1411,53 @@ class SqueakDb:
                 self._parse_sent_payment(row) for row in rows]
             return sent_payments
 
+    def get_sent_payments_for_peer(
+            self,
+            peer_address: PeerAddress,
+            limit: int,
+            last_sent_payment: Optional[SentPayment],
+    ) -> List[SentPayment]:
+        """ Get sent payments for a peer. """
+        last_created_time = last_sent_payment.created_time_ms if last_sent_payment else self.timestamp_now_ms
+        last_payment_hash = last_sent_payment.payment_hash if last_sent_payment else MAX_HASH
+        logger.info("""Get sent payments db query with
+        peer_address: {}
+        limit: {}
+        last_created_time: {}
+        last_payment_hash: {}
+        """.format(
+            peer_address,
+            limit,
+            last_created_time,
+            last_payment_hash.hex(),
+        ))
+        s = (
+            select([self.sent_payments])
+            .where(self.received_payments.c.peer_network == peer_address.network.name)
+            .where(self.received_payments.c.peer_host == peer_address.host)
+            .where(self.received_payments.c.peer_port == peer_address.port)
+            .where(
+                tuple_(
+                    self.sent_payments.c.created_time_ms,
+                    self.sent_payments.c.payment_hash,
+                ) < tuple_(
+                    last_created_time,
+                    last_payment_hash,
+                )
+            )
+            .order_by(
+                self.sent_payments.c.created_time_ms.desc(),
+                self.sent_payments.c.payment_hash.desc(),
+            )
+            .limit(limit)
+        )
+        with self.get_connection() as connection:
+            result = connection.execute(s)
+            rows = result.fetchall()
+            sent_payments = [
+                self._parse_sent_payment(row) for row in rows]
+            return sent_payments
+
     def get_sent_payment(self, sent_payment_id: int) -> Optional[SentPayment]:
         """ Get sent payment by id. """
         s = (
@@ -1570,6 +1720,53 @@ class SqueakDb:
                 self._parse_received_payment(row) for row in rows]
             return received_payments
 
+    def get_received_payments_for_peer(
+            self,
+            peer_address: PeerAddress,
+            limit: int,
+            last_received_payment: Optional[ReceivedPayment],
+    ) -> List[ReceivedPayment]:
+        """ Get received payments for a squeak. """
+        last_created_time = last_received_payment.created_time_ms if last_received_payment else self.timestamp_now_ms
+        last_payment_hash = last_received_payment.payment_hash if last_received_payment else MAX_HASH
+        logger.info("""Get received payments db query with
+        peer_address: {}
+        limit: {}
+        last_created_time: {}
+        last_payment_hash: {}
+        """.format(
+            peer_address,
+            limit,
+            last_created_time,
+            last_payment_hash.hex(),
+        ))
+        s = (
+            select([self.received_payments])
+            .where(self.received_payments.c.peer_network == peer_address.network.name)
+            .where(self.received_payments.c.peer_host == peer_address.host)
+            .where(self.received_payments.c.peer_port == peer_address.port)
+            .where(
+                tuple_(
+                    self.received_payments.c.created_time_ms,
+                    self.received_payments.c.payment_hash,
+                ) < tuple_(
+                    last_created_time,
+                    last_payment_hash,
+                )
+            )
+            .order_by(
+                self.received_payments.c.created_time_ms.desc(),
+                self.received_payments.c.payment_hash.desc(),
+            )
+            .limit(limit)
+        )
+        with self.get_connection() as connection:
+            result = connection.execute(s)
+            rows = result.fetchall()
+            received_payments = [
+                self._parse_received_payment(row) for row in rows]
+            return received_payments
+
     def get_latest_settle_index(self) -> Optional[int]:
         """ Get the lnd settled index of the most recent received payment. """
         s = select(
@@ -1713,6 +1910,45 @@ class SqueakDb:
             sent_payment_summary = self._parse_sent_payment_summary(row)
             return sent_payment_summary
 
+    def get_received_payment_summary_for_peer(self, peer_address: PeerAddress) -> ReceivedPaymentSummary:
+        """ Get received payment summary for a single peer. """
+        s = (
+            select([
+                func.count().label("num_payments_received"),
+                func.sum(self.received_payments.c.price_msat).label(
+                    "total_amount_received_msat"),
+            ])
+            .select_from(self.received_payments)
+            .where(self.received_payments.c.peer_network == peer_address.network.name)
+            .where(self.received_payments.c.peer_host == peer_address.host)
+            .where(self.received_payments.c.peer_port == peer_address.port)
+        )
+        with self.get_connection() as connection:
+            result = connection.execute(s)
+            row = result.fetchone()
+            received_payment_summary = self._parse_received_payment_summary(
+                row)
+            return received_payment_summary
+
+    def get_sent_payment_summary_for_peer(self, peer_address: PeerAddress) -> SentPaymentSummary:
+        """ Get sent payment summary for a peer. """
+        s = (
+            select([
+                func.count().label("num_payments_sent"),
+                func.sum(self.sent_payments.c.price_msat).label(
+                    "total_amount_sent_msat"),
+            ])
+            .select_from(self.sent_payments)
+            .where(self.received_payments.c.peer_network == peer_address.network.name)
+            .where(self.received_payments.c.peer_host == peer_address.host)
+            .where(self.received_payments.c.peer_port == peer_address.port)
+        )
+        with self.get_connection() as connection:
+            result = connection.execute(s)
+            row = result.fetchone()
+            sent_payment_summary = self._parse_sent_payment_summary(row)
+            return sent_payment_summary
+
     def insert_config(self, user_config: UserConfig) -> Optional[str]:
         """ Insert a new config.
 
@@ -1838,6 +2074,7 @@ class SqueakDb:
             is_unlocked=is_locked,
             secret_key=(row["secret_key"]),
             liked_time_ms=liked_time_ms,
+            num_replies=row["num_replies"],
             content=row["content"],
             squeak_profile=profile,
             recipient_squeak_profile=recipient_profile,
