@@ -28,6 +28,7 @@ from squeaknode.bitcoin.block_info import BlockInfo
 from squeaknode.core.download_result import DownloadResult
 from squeaknode.core.lightning_address import LightningAddressHostPort
 from squeaknode.core.offer import Offer
+from squeaknode.core.payment_summary import PaymentSummary
 from squeaknode.core.peer_address import Network
 from squeaknode.core.peer_address import PeerAddress
 from squeaknode.core.received_offer import ReceivedOffer
@@ -306,6 +307,7 @@ def squeak_entry_locked(
         squeak_profile=signing_profile,
         recipient_squeak_profile=recipient_contact_profile,
         liked_time_ms=None,
+        num_replies=0,
         content=None,
     )
 
@@ -555,6 +557,17 @@ def sent_payment_summary(
     )
 
 
+@pytest.fixture
+def payment_summary(
+        received_payment_summary,
+        sent_payment_summary,
+):
+    yield PaymentSummary(
+        sent_payment_summary=sent_payment_summary,
+        received_payment_summary=received_payment_summary,
+    )
+
+
 @pytest.fixture
 def download_result():
     yield DownloadResult(
